==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkQuadricClustering.java <==
// java wrapper for vtkQuadricClustering object
//

package vtk;
import vtk.*;

public class vtkQuadricClustering extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNumberOfXDivisions_2(int id0);
  public void SetNumberOfXDivisions(int id0)
    { SetNumberOfXDivisions_2(id0); }

  private native void SetNumberOfYDivisions_3(int id0);
  public void SetNumberOfYDivisions(int id0)
    { SetNumberOfYDivisions_3(id0); }

  private native void SetNumberOfZDivisions_4(int id0);
  public void SetNumberOfZDivisions(int id0)
    { SetNumberOfZDivisions_4(id0); }

  private native int GetNumberOfXDivisions_5();
  public int GetNumberOfXDivisions()
    { return GetNumberOfXDivisions_5(); }

  private native int GetNumberOfYDivisions_6();
  public int GetNumberOfYDivisions()
    { return GetNumberOfYDivisions_6(); }

  private native int GetNumberOfZDivisions_7();
  public int GetNumberOfZDivisions()
    { return GetNumberOfZDivisions_7(); }

  private native void SetNumberOfDivisions_8(int id0[]);
  public void SetNumberOfDivisions(int id0[])
    { SetNumberOfDivisions_8(id0); }

  private native void SetNumberOfDivisions_9(int id0,int id1,int id2);
  public void SetNumberOfDivisions(int id0,int id1,int id2)
    { SetNumberOfDivisions_9(id0,id1,id2); }

  private native int[]  GetNumberOfDivisions_10();
  public int[]  GetNumberOfDivisions()
    { return GetNumberOfDivisions_10(); }

  private native void GetNumberOfDivisions_11(int id0[]);
  public void GetNumberOfDivisions(int id0[])
    { GetNumberOfDivisions_11(id0); }

  private native void SetAutoAdjustNumberOfDivisions_12(int id0);
  public void SetAutoAdjustNumberOfDivisions(int id0)
    { SetAutoAdjustNumberOfDivisions_12(id0); }

  private native int GetAutoAdjustNumberOfDivisions_13();
  public int GetAutoAdjustNumberOfDivisions()
    { return GetAutoAdjustNumberOfDivisions_13(); }

  private native void AutoAdjustNumberOfDivisionsOn_14();
  public void AutoAdjustNumberOfDivisionsOn()
    { AutoAdjustNumberOfDivisionsOn_14(); }

  private native void AutoAdjustNumberOfDivisionsOff_15();
  public void AutoAdjustNumberOfDivisionsOff()
    { AutoAdjustNumberOfDivisionsOff_15(); }

  private native void SetDivisionOrigin_16(double id0,double id1,double id2);
  public void SetDivisionOrigin(double id0,double id1,double id2)
    { SetDivisionOrigin_16(id0,id1,id2); }

  private native void SetDivisionOrigin_17(double id0[]);
  public void SetDivisionOrigin(double id0[])
    { SetDivisionOrigin_17(id0); }

  private native double[] GetDivisionOrigin_18();
  public double[] GetDivisionOrigin()
    { return GetDivisionOrigin_18(); }

  private native void SetDivisionSpacing_19(double id0,double id1,double id2);
  public void SetDivisionSpacing(double id0,double id1,double id2)
    { SetDivisionSpacing_19(id0,id1,id2); }

  private native void SetDivisionSpacing_20(double id0[]);
  public void SetDivisionSpacing(double id0[])
    { SetDivisionSpacing_20(id0); }

  private native double[] GetDivisionSpacing_21();
  public double[] GetDivisionSpacing()
    { return GetDivisionSpacing_21(); }

  private native void SetUseInputPoints_22(int id0);
  public void SetUseInputPoints(int id0)
    { SetUseInputPoints_22(id0); }

  private native int GetUseInputPoints_23();
  public int GetUseInputPoints()
    { return GetUseInputPoints_23(); }

  private native void UseInputPointsOn_24();
  public void UseInputPointsOn()
    { UseInputPointsOn_24(); }

  private native void UseInputPointsOff_25();
  public void UseInputPointsOff()
    { UseInputPointsOff_25(); }

  private native void SetUseFeatureEdges_26(int id0);
  public void SetUseFeatureEdges(int id0)
    { SetUseFeatureEdges_26(id0); }

  private native int GetUseFeatureEdges_27();
  public int GetUseFeatureEdges()
    { return GetUseFeatureEdges_27(); }

  private native void UseFeatureEdgesOn_28();
  public void UseFeatureEdgesOn()
    { UseFeatureEdgesOn_28(); }

  private native void UseFeatureEdgesOff_29();
  public void UseFeatureEdgesOff()
    { UseFeatureEdgesOff_29(); }

  private native long GetFeatureEdges_30();
  public vtkFeatureEdges GetFeatureEdges() {
    long temp = GetFeatureEdges_30();

    if (temp == 0) return null;
    return (vtkFeatureEdges)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetUseFeaturePoints_31(int id0);
  public void SetUseFeaturePoints(int id0)
    { SetUseFeaturePoints_31(id0); }

  private native int GetUseFeaturePoints_32();
  public int GetUseFeaturePoints()
    { return GetUseFeaturePoints_32(); }

  private native void UseFeaturePointsOn_33();
  public void UseFeaturePointsOn()
    { UseFeaturePointsOn_33(); }

  private native void UseFeaturePointsOff_34();
  public void UseFeaturePointsOff()
    { UseFeaturePointsOff_34(); }

  private native void SetFeaturePointsAngle_35(double id0);
  public void SetFeaturePointsAngle(double id0)
    { SetFeaturePointsAngle_35(id0); }

  private native double GetFeaturePointsAngleMinValue_36();
  public double GetFeaturePointsAngleMinValue()
    { return GetFeaturePointsAngleMinValue_36(); }

  private native double GetFeaturePointsAngleMaxValue_37();
  public double GetFeaturePointsAngleMaxValue()
    { return GetFeaturePointsAngleMaxValue_37(); }

  private native double GetFeaturePointsAngle_38();
  public double GetFeaturePointsAngle()
    { return GetFeaturePointsAngle_38(); }

  private native void SetUseInternalTriangles_39(int id0);
  public void SetUseInternalTriangles(int id0)
    { SetUseInternalTriangles_39(id0); }

  private native int GetUseInternalTriangles_40();
  public int GetUseInternalTriangles()
    { return GetUseInternalTriangles_40(); }

  private native void UseInternalTrianglesOn_41();
  public void UseInternalTrianglesOn()
    { UseInternalTrianglesOn_41(); }

  private native void UseInternalTrianglesOff_42();
  public void UseInternalTrianglesOff()
    { UseInternalTrianglesOff_42(); }

  private native void StartAppend_43(double id0,double id1,double id2,double id3,double id4,double id5);
  public void StartAppend(double id0,double id1,double id2,double id3,double id4,double id5)
    { StartAppend_43(id0,id1,id2,id3,id4,id5); }

  private native void Append_44(vtkPolyData id0);
  public void Append(vtkPolyData id0)
    { Append_44(id0); }

  private native void EndAppend_45();
  public void EndAppend()
    { EndAppend_45(); }

  private native void SetCopyCellData_46(int id0);
  public void SetCopyCellData(int id0)
    { SetCopyCellData_46(id0); }

  private native int GetCopyCellData_47();
  public int GetCopyCellData()
    { return GetCopyCellData_47(); }

  private native void CopyCellDataOn_48();
  public void CopyCellDataOn()
    { CopyCellDataOn_48(); }

  private native void CopyCellDataOff_49();
  public void CopyCellDataOff()
    { CopyCellDataOff_49(); }

  private native void SetPreventDuplicateCells_50(int id0);
  public void SetPreventDuplicateCells(int id0)
    { SetPreventDuplicateCells_50(id0); }

  private native int GetPreventDuplicateCells_51();
  public int GetPreventDuplicateCells()
    { return GetPreventDuplicateCells_51(); }

  private native void PreventDuplicateCellsOn_52();
  public void PreventDuplicateCellsOn()
    { PreventDuplicateCellsOn_52(); }

  private native void PreventDuplicateCellsOff_53();
  public void PreventDuplicateCellsOff()
    { PreventDuplicateCellsOff_53(); }

  public vtkQuadricClustering() { super(); }

  public vtkQuadricClustering(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-5-aarch64.pkg.tar.xz: vtk/vtkQuadricClustering.java <==
// java wrapper for vtkQuadricClustering object
//

package vtk;
import vtk.*;

public class vtkQuadricClustering extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNumberOfXDivisions_2(int id0);
  public void SetNumberOfXDivisions(int id0)
    { SetNumberOfXDivisions_2(id0); }

  private native void SetNumberOfYDivisions_3(int id0);
  public void SetNumberOfYDivisions(int id0)
    { SetNumberOfYDivisions_3(id0); }

  private native void SetNumberOfZDivisions_4(int id0);
  public void SetNumberOfZDivisions(int id0)
    { SetNumberOfZDivisions_4(id0); }

  private native int GetNumberOfXDivisions_5();
  public int GetNumberOfXDivisions()
    { return GetNumberOfXDivisions_5(); }

  private native int GetNumberOfYDivisions_6();
  public int GetNumberOfYDivisions()
    { return GetNumberOfYDivisions_6(); }

  private native int GetNumberOfZDivisions_7();
  public int GetNumberOfZDivisions()
    { return GetNumberOfZDivisions_7(); }

  private native void SetNumberOfDivisions_8(int id0[]);
  public void SetNumberOfDivisions(int id0[])
    { SetNumberOfDivisions_8(id0); }

  private native void SetNumberOfDivisions_9(int id0,int id1,int id2);
  public void SetNumberOfDivisions(int id0,int id1,int id2)
    { SetNumberOfDivisions_9(id0,id1,id2); }

  private native int[]  GetNumberOfDivisions_10();
  public int[]  GetNumberOfDivisions()
    { return GetNumberOfDivisions_10(); }

  private native void GetNumberOfDivisions_11(int id0[]);
  public void GetNumberOfDivisions(int id0[])
    { GetNumberOfDivisions_11(id0); }

  private native void SetAutoAdjustNumberOfDivisions_12(int id0);
  public void SetAutoAdjustNumberOfDivisions(int id0)
    { SetAutoAdjustNumberOfDivisions_12(id0); }

  private native int GetAutoAdjustNumberOfDivisions_13();
  public int GetAutoAdjustNumberOfDivisions()
    { return GetAutoAdjustNumberOfDivisions_13(); }

  private native void AutoAdjustNumberOfDivisionsOn_14();
  public void AutoAdjustNumberOfDivisionsOn()
    { AutoAdjustNumberOfDivisionsOn_14(); }

  private native void AutoAdjustNumberOfDivisionsOff_15();
  public void AutoAdjustNumberOfDivisionsOff()
    { AutoAdjustNumberOfDivisionsOff_15(); }

  private native void SetDivisionOrigin_16(double id0,double id1,double id2);
  public void SetDivisionOrigin(double id0,double id1,double id2)
    { SetDivisionOrigin_16(id0,id1,id2); }

  private native void SetDivisionOrigin_17(double id0[]);
  public void SetDivisionOrigin(double id0[])
    { SetDivisionOrigin_17(id0); }

  private native double[] GetDivisionOrigin_18();
  public double[] GetDivisionOrigin()
    { return GetDivisionOrigin_18(); }

  private native void SetDivisionSpacing_19(double id0,double id1,double id2);
  public void SetDivisionSpacing(double id0,double id1,double id2)
    { SetDivisionSpacing_19(id0,id1,id2); }

  private native void SetDivisionSpacing_20(double id0[]);
  public void SetDivisionSpacing(double id0[])
    { SetDivisionSpacing_20(id0); }

  private native double[] GetDivisionSpacing_21();
  public double[] GetDivisionSpacing()
    { return GetDivisionSpacing_21(); }

  private native void SetUseInputPoints_22(int id0);
  public void SetUseInputPoints(int id0)
    { SetUseInputPoints_22(id0); }

  private native int GetUseInputPoints_23();
  public int GetUseInputPoints()
    { return GetUseInputPoints_23(); }

  private native void UseInputPointsOn_24();
  public void UseInputPointsOn()
    { UseInputPointsOn_24(); }

  private native void UseInputPointsOff_25();
  public void UseInputPointsOff()
    { UseInputPointsOff_25(); }

  private native void SetUseFeatureEdges_26(int id0);
  public void SetUseFeatureEdges(int id0)
    { SetUseFeatureEdges_26(id0); }

  private native int GetUseFeatureEdges_27();
  public int GetUseFeatureEdges()
    { return GetUseFeatureEdges_27(); }

  private native void UseFeatureEdgesOn_28();
  public void UseFeatureEdgesOn()
    { UseFeatureEdgesOn_28(); }

  private native void UseFeatureEdgesOff_29();
  public void UseFeatureEdgesOff()
    { UseFeatureEdgesOff_29(); }

  private native long GetFeatureEdges_30();
  public vtkFeatureEdges GetFeatureEdges() {
    long temp = GetFeatureEdges_30();

    if (temp == 0) return null;
    return (vtkFeatureEdges)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetUseFeaturePoints_31(int id0);
  public void SetUseFeaturePoints(int id0)
    { SetUseFeaturePoints_31(id0); }

  private native int GetUseFeaturePoints_32();
  public int GetUseFeaturePoints()
    { return GetUseFeaturePoints_32(); }

  private native void UseFeaturePointsOn_33();
  public void UseFeaturePointsOn()
    { UseFeaturePointsOn_33(); }

  private native void UseFeaturePointsOff_34();
  public void UseFeaturePointsOff()
    { UseFeaturePointsOff_34(); }

  private native void SetFeaturePointsAngle_35(double id0);
  public void SetFeaturePointsAngle(double id0)
    { SetFeaturePointsAngle_35(id0); }

  private native double GetFeaturePointsAngleMinValue_36();
  public double GetFeaturePointsAngleMinValue()
    { return GetFeaturePointsAngleMinValue_36(); }

  private native double GetFeaturePointsAngleMaxValue_37();
  public double GetFeaturePointsAngleMaxValue()
    { return GetFeaturePointsAngleMaxValue_37(); }

  private native double GetFeaturePointsAngle_38();
  public double GetFeaturePointsAngle()
    { return GetFeaturePointsAngle_38(); }

  private native void SetUseInternalTriangles_39(int id0);
  public void SetUseInternalTriangles(int id0)
    { SetUseInternalTriangles_39(id0); }

  private native int GetUseInternalTriangles_40();
  public int GetUseInternalTriangles()
    { return GetUseInternalTriangles_40(); }

  private native void UseInternalTrianglesOn_41();
  public void UseInternalTrianglesOn()
    { UseInternalTrianglesOn_41(); }

  private native void UseInternalTrianglesOff_42();
  public void UseInternalTrianglesOff()
    { UseInternalTrianglesOff_42(); }

  private native void StartAppend_43(double id0,double id1,double id2,double id3,double id4,double id5);
  public void StartAppend(double id0,double id1,double id2,double id3,double id4,double id5)
    { StartAppend_43(id0,id1,id2,id3,id4,id5); }

  private native void Append_44(vtkPolyData id0);
  public void Append(vtkPolyData id0)
    { Append_44(id0); }

  private native void EndAppend_45();
  public void EndAppend()
    { EndAppend_45(); }

  private native void SetCopyCellData_46(int id0);
  public void SetCopyCellData(int id0)
    { SetCopyCellData_46(id0); }

  private native int GetCopyCellData_47();
  public int GetCopyCellData()
    { return GetCopyCellData_47(); }

  private native void CopyCellDataOn_48();
  public void CopyCellDataOn()
    { CopyCellDataOn_48(); }

  private native void CopyCellDataOff_49();
  public void CopyCellDataOff()
    { CopyCellDataOff_49(); }

  private native void SetPreventDuplicateCells_50(int id0);
  public void SetPreventDuplicateCells(int id0)
    { SetPreventDuplicateCells_50(id0); }

  private native int GetPreventDuplicateCells_51();
  public int GetPreventDuplicateCells()
    { return GetPreventDuplicateCells_51(); }

  private native void PreventDuplicateCellsOn_52();
  public void PreventDuplicateCellsOn()
    { PreventDuplicateCellsOn_52(); }

  private native void PreventDuplicateCellsOff_53();
  public void PreventDuplicateCellsOff()
    { PreventDuplicateCellsOff_53(); }

  public vtkQuadricClustering() { super(); }

  public vtkQuadricClustering(long id) { super(id); }
  public native long   VTKInit();

}
